<?php
/*	=====================================================
	section_select, Version 1.05.000
	=====================================================

$module_directory     = 'section_select';
$module_name          = 'Section Select';
$module_function      = 'page';
$module_version       = '1.05.000';
$module_platform      = '2.x';
$module_author        = 'Wolfgang Studer';
$module_license       = 'GNU General Public License';
$module_license_terms = '-';
$module_description   = 'select another section and show that content here on runtime';
$module_guid          = '876e64a1-5e1d-462e-aa3a-043552be1b84';
$module_home          = 'www.wolfgangstuder.ch | www.lepton-cms.com';
$lepador_link         = 'http://www.lepton-cms.com/lepador/modules/section_select.php';
$forum_link           = 'http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059';

=====================================================

INTRO
==================================

A module for the LEPTON CMS software.

This module allows to use a section multiple times on same or different pages.
The use of such a refered section can be bound to a condition.

>> This module is a fork from old module section_picker
>> Created by Ruud Eisinga and Sare

However there are several enhancements made in here:
- general enhancements
  + use of lepton security
  + use of TWIG template engine
- backend handling enhancements
  + various enhancements of refered section index
    * properly sorted according to page & section tree
    * splitted selection for page & sections, helpfull in bigger sites
    * load sections depending on selected page via Ajax call
    * more information are provided
    * leptons section name is shown if available
    * validity dates of sections are shown
    * pages without access right permissions are not listed
  + conditions added
- Frontend visibility enhancements
  + pages (of refered sections) marked for deletion are no longer shown
  + refered sections no longer valid are no longer shown
  + refered sections not yet valid are no longer shown
  + sections of pages which can not be shown due to visibility setting are no longer shown
  + output shown only if condition fits

Note: when refering to a section on a page using a different frontend template than current,
the result might not fit into your expectations.

This module supports the module "lib_logger". With "lib_logger",
errors, activities and SQLs can be saved in a database table and shown via the module
"logger".
The modules "lib_logger" and "logger" are optional and not
mandatory for the usage of this module.

This module supports the module "lib_dependency" to secure the availability of
dependencies during de-installations.
The module "lib_dependency" is optional and not mandatory for the usage of this
module.
The module can be installed later on, defined dependencies will be semi-automatically
registered (register_dependency.php).
See README.en.txt of "lib_dependency" for more details about.

PRE-REQUIREMENTS
==================================
>=       2.2 : LEPTON_VERSION
>=       5.6 : PHP_VERSION
>=  1.04.000 : WB_ADDONS[ 'lib_setuphelper' ]
>=  1.24.0.0 : WB_ADDONS[ 'lib_twig' ]
>=  0.03.001 : WB_ADDONS[ 'lib_dependency' ] (optional)
>=  0.05.002 : WB_ADDONS[ 'lib_logger' ] (optional)

INSTALLATION
==================================

1. Download the latest version from
	http://www.lepton-cms.com/lepador/modules/section_select.php
2. Log into your Lepton CMS backend
3. Go to Addons -> Modules
4. In the "Install Module" section, enter the path to the section_select zip file
	that you downloaded in step 1, and choose the "Install" button.


DE-INSTALLATION
==================================

1. Log into your Lepton CMS backend
2. Go to Addons -> Modules
3. In the "Uninstall Module" section, select the module "section_select",
	and choose the "Uninstall" button.

USING section_select
==================================

Create first a new section on any page using "Art" = "section_select".

Within this module section you have now:
- a list of various form fields for selecting the referenced section
- a possibility to set the module active/inactive
- a notes field for internal notes on this section.
- a "Save" button
- a "Cancel" button


Per default just 2 conditions are available.
You can set own conditions in lib.backend.config in template folder, see below.
Example of conditions might be:
	$secsel_conditions[ 'MONDAY' ]		= addslashes( 'return ( date("N",time() ) == 1 );' );
	$secsel_conditions[ 'TUESDAY' ]	= addslashes( 'return ( date("N",time() ) == 2 );' );
	$secsel_conditions[ 'WEDNESDAY' ]	= addslashes( 'return ( date("N",time() ) == 3 );' );
	$secsel_conditions[ 'THURSDAY' ]	= addslashes( 'return ( date("N",time() ) == 4 );' );
	$secsel_conditions[ 'FRIDAY' ]		= addslashes( 'return ( date("N",time() ) == 5 );' );
	$secsel_conditions[ 'SATURDAY' ]	= addslashes( 'return ( date("N",time() ) == 6 );' );
	$secsel_conditions[ 'SUNDAY' ]		= addslashes( 'return ( date("N",time() ) == 7 );' );
	$secsel_conditions[ 'EARLY' ]		= addslashes( 'return (( date("H",time() ) >= 6 ) AND ( date("H",time() ) < 9 ));' );
	$secsel_conditions[ 'MORNING' ]	= addslashes( 'return (( date("H",time() ) >= 9 ) AND ( date("H",time() ) < 12 ));' );
	$secsel_conditions[ 'NOON' ]		= addslashes( 'return  ( date("H",time() ) == 12 );' );
	$secsel_conditions[ 'AFTERNOON' ]	= addslashes( 'return (( date("H",time() ) >= 13 ) AND ( date("H",time() ) < 18 ));' );
	$secsel_conditions[ 'EVENING' ]	= addslashes( 'return (( date("H",time() ) >= 18 ) AND ( date("H",time() ) < 22 ));' );
	$secsel_conditions[ 'NIGHT' ]		= addslashes( 'return (( date("H",time() ) >= 22 ) OR  ( date("H",time() ) < 6 ));' );

Don't forget to define the translations like
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'MONDAY' ]		= 'Monday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'TUESDAY' ]		= 'Tuesday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'WEDNESDAY' ]	= 'Wednesday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'THURSDAY' ]	= 'Thursday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'FRIDAY' ]		= 'Friday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'SATURDAY' ]	= 'Saturday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'SUNDAY' ]		= 'Sunday';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'EARLY' ]		= 'From 06:00 until 08:59';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'MORNING' ]		= 'From 09:00 until 11:59';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'NOON' ]		= 'From 12:00 until 12:59';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'AFTERNOON' ]	= 'From 13:00 until 17:59';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'EVENING' ]		= 'From 18:00 until 21:59';
	$MOD_SECTION_SELECT[ 'CONDITION' ][ 'NIGHT' ]		= 'From 22:00 until 05:59';



USAGE of lib_dependency
==================================

Note that this functionality is available only if "lib_dependency" is installed!

During normal usage of the module "section_select", you will not notice anything
about "lib_dependency".

Only in the following cases you will see the availability of "lib_dependency":
- when someone tries to de-install any of the modules registered as childs of
"section_select", an error appears and de-installation of the child module is
forbidden ("section_select" is parent).
- when someone tries to de-install "section_select" and "section_select" is
registered as child of another module, an error appears and de-installation of
this "section_select" module is forbidden ("section_select" is child).

OWN ENHANCEMENTS
===========================

This module is build in a way that it can be enhanced by system administrator at various
points without any risk that enhancements gets lost during next updates.
Hereafter the points & files:

Variables used:
- {LEPTON_PATH}   = the LEPTON CMS installation path
- {DEFAULT_THEME} = the backend theme used
- {TEMPLATE}      = the frontend template used
- {COMPONENT}     = the component name, e.g. "modify_optionizer"
- {LANGUAGE}      = the currently used language code, uppercase

- {BACKEND_PATH}  = {LEPTON_PATH}/templates/{DEFAULT_THEME}/backend/section_select
- {FRONTEND_PATH} = {LEPTON_PATH}/templates/{TEMPLATE}/frontend/section_select


For backend:
- {BACKEND_PATH}/backend.css
	>> use this file to overwrite the default layout styles.
		If this file exists, the default file will not be used!

- {BACKEND_PATH}/languages/{LANGUAGE}.php
	>> use this file to overwrite the default provided text.
		This file is loaded after the standard file have been processed.

- {BACKEND_PATH}/lib/lib.backend.config.{COMPONENT}.php
	>> you can overwrite here default config settings.
		This file is loaded after the standard file have been processed.

- {BACKEND_PATH}/lib/lib.data.{COMPONENT}.php
	>> data have been retrieved. use this script when you want to modify the data before
		they are passed to the TWIG template engine
		This file is loaded after the standard file have been processed.

- {BACKEND_PATH}/lib/lib.twig.{COMPONENT}.php
	>> use this for passing additional values towards the TWIG template.
		This file is loaded after the standard file have been processed.

- {BACKEND_PATH}/templates/backend/{COMPONENT}.lte
	>> use this file to use your own template
		If this file exists, the default file will not be used!
	Note that you can use also a template with a different name by specifying it as:
		// define twig template
		$twigTemplate =  '<<your template name>>';
	in: {BACKEND_PATH}/lib/lib.twig.{COMPONENT}.php

For frontend:
- {FRONTEND_PATH}/frontend.css
	>> use this fiel to overwrite the default layout styles
		If this file exists, the default file will not be used!

- {FRONTEND_PATH}/languages/{LANGUAGE}.php
	>> use this file to overwrite the default provided text.
		This file is loaded after the standard file have been processed.

- {FRONTEND_PATH}/lib/lib.frontend.config.{COMPONENT}.php
	>> you can overwrite here default config settings.
		This file is loaded after the standard file have been processed.

- {FRONTEND_PATH}/lib/lib.data.{COMPONENT}.php
	>> data have been retrieved. use this script when you want to modify the data before
		they are passed to the TWIG template engine
		This file is loaded after the standard file have been processed.

- {FRONTEND_PATH}/lib/lib.twig.{COMPONENT}.php
	>> use this for passing additional values towards the TWIG template.
		This file is loaded after the standard file have been processed.

- {FRONTEND_PATH}/templates/frontend/{COMPONENT}.lte
	>> use this file to use your own template
		If this file exists, the default file will not be used!
	Note that you can use also a template with a different name by specifying it as:
		// define twig template
		$twigTemplate =  '<<your template name>>';
	in: {FRONTEND_PATH}/lib/lib.twig.{COMPONENT}.php



FURTHER DOCUMENTATION
===========================

Further documentation about this module can be found in the LEPTON CMS forum at
http://forum.lepton-cms.org/index.php


Enjoy!
*/
?>
