<?php

/**  // € // to identify files as UTF8
 * select another section and show that content here on runtime
 *
 * @module          section_select
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.05.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/section_select.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/*	**************************************
	*
	* check for & delete remaining registrations
	*
	**************************************
*/
// include dependency library only when exists
// de-register the childs
	$include = LEPTON_PATH . '/modules/lib_dependency/library.php';
	if ( file_exists( $include ) == TRUE ):
		include_once( $include );

		// when parent dependencies are available, send a mail to webmaster with existing
		// registrations (remove or comment if you don't want this)
		dependencyMail( 'section_select' );

		// when child dependencies are available, remove them
		dependencyRemove( 'section_select' );

		// note that in case remaining 'parent as child' dependencies are available,
		// the function 'dependencyRemove' triggers an '$admin->print_error' process
		// which somehow stops the further uninstall processing!
	endif;




/*	**************************************
	*
	* do DB setup activities for current script
	*
	**************************************
*/

// get current trigger_code based on script name of current request
	$trigger_code = mb_convert_case( basename( __FILE__, '.php' ), MB_CASE_UPPER, 'UTF-8' );
	$secsel_modulePath = dirname( __FILE__ ) . DIRECTORY_SEPARATOR;
	$cleanupFiles = array();

// load setup & execute
	if (( is_file( $secsel_modulePath . '_setup.php' )								== TRUE )
	and ( is_file( LEPTON_PATH . '/modules/lib_setuphelper/library.php' )	== TRUE )):
		// get $module_DB_setup
		include_once( $secsel_modulePath . '_setup.php' );

		// check if there is something to be done on current trigger_code
		if (( count( $module_DB_setup ) > 0 )
		and ( array_key_exists( $trigger_code, $module_DB_setup ) == TRUE )):

			// define the module name
			$tmp = explode( DIRECTORY_SEPARATOR, dirname( __FILE__ ));
			$secsel_module = array_pop( $tmp );

			// define the module version
			// already set in: UPGRADE, INSTALL
			// missing in: UNINSTALL, ADD, DELETE
			if ( isset( $module_version ) == FALSE ):
				include( $secsel_modulePath . 'info.php' );
			endif;

			// define placeholders when needed.
			// Placeholders can be used in module_DB_setup array.
			$placeholders = array(    '#PAGE_ID#'		=> ( isset( $page_id ) == TRUE ? $page_id : 0 )
									, '#SECTION_ID#'	=> ( isset( $section_id ) == TRUE ? $section_id : 0 )
									, '#USER_ID#'		=> ( isset( $admin ) == TRUE ? $admin->get_user_id() : 0 )
									);

			// With the "->setOptions( 'TMP_ID', 'XXXXXXXXXXXXXXX' )" the temp table name can be defined,
			// used in case of alter table is needed.
			// It should be a unique ID not used as a real table. However it can be the same for all modules.
			// Default is 'XXXXXXXXXXXXXXX', so default temp table name is "TABLE_PREFIX . 'tmp_' . 'XXXXXXXXXXXXXXX'"


			// Logging can be set on various levels, on any combination or for all.
			// 0 = no logging
			// 1 = errors
			// 4 = infos
			// 5 = errors & infos
			// 8 = notice
			// 9 = errors & notice
			// 12 = infos & notice
			// 13 = all
			//
			// The default logging depends whether the module "LOGGER" is installed or not.
			// When not installed, logging is switched off.
			// When installed, default logging is 13 for trigger_codes INSTALL, UPGRADE, UNINSTALL and 1 for ADD,DELETE
			// You can swap default for a single trigger_code like "->setOptions( 'LOGGING', array( 'DELETE' => 1 ))"
			// or for all at once "->setOptions( 'LOGGING', 13 )"
			// or you can reset to default with "->setOptions( 'LOGGING', 'RESET' )"
			$logging = 'RESET';

			// load setup helper
			// must be after setting of logging but before setting of modulefiles
			require_once( LEPTON_PATH . '/modules/lib_setuphelper/library.php' );


			// during INSTALL/UPGRADE process, also the file system can be cleaned
			// However it is normally needed only in UPGRADE process
			// Note that cleaning means creating of an archive subfolder and moving all obsolete files into.
			$moduleFiles = array();
			if ( $trigger_code == 'UPGRADE' ):
				// As we need a list of all "should be" files including js, css, jpg, ...
				// We build it based on the last modification date set during install/upgrade process
				// after creating/updating the files in the module folder.
				// Base date is file date of info.php - 2 minutes.
				// All files newer than this are in the list .... ;-)
				$moduleFiles = dbs_get_last_file_list( $secsel_modulePath );

				// in addition or instead of $moduleFiles, you can use also
				// - 'WHITELIST'	= array of files (full path) which needs to be kept anyhow
				// - 'BLACKLIST'	= array of files (full path) which needs to be moved into archive
			endif;

			// run defined activities
			$status = $DB_setup->setConfig( $module_DB_setup )
							->setOptions( 'MODULE', $secsel_module )
							->setOptions( 'MODULEPATH', $secsel_modulePath )
							->setOptions( 'MODULEVERSION', $module_version )
							->setOptions( 'PLACEHOLDERS', $placeholders )
							->setOptions( 'MODULEFILES', $moduleFiles )
							->process( $trigger_code );

			// show errors
			if ( $status == FALSE ):
				$admin->print_error( $DB_setup->getErrors() );
				return FALSE;
			endif;
		endif;

		// we might have loaded info.ph from libraries, due to INSTALL/UPGRADE does not work properly.
		// So we have to load current modules info.php again!
		include( $secsel_modulePath . 'info.php' );
	endif;

?>
